# Main codebase

This directory contains logic used by the reweight library for PolicyEngine, including the `reweight.py` reweighting function and the `process_data.py` automated data generation script.
